@@ -269,12 +269,12 @@ let finish_head resp cgi =
   Delivered
 
 let with_pair rex str proc =
-  match Pcre.extract ~rex ~full_match: false str with
+  match Re.Pcre.extract ~rex str with
   | [| a; b |] -> proc (a, b)
   | _ -> assert false
 
-let status_re = Pcre.regexp "^HTTP/\\d+(?:\\.\\d+)?\\s+(\\d{3})(?:\\s+(.*?)\\s*)?$"
-let header_re = Pcre.regexp "^(.*?):\\s*(.*?)\\s*$"
+let status_re = Re.Pcre.regexp "^HTTP/\\d+(?:\\.\\d+)?\\s+(\\d{3})(?:\\s+(.*?)\\s*)?$"
+let header_re = Re.Pcre.regexp "^(.*?):\\s*(.*?)\\s*$"
 
 let process_header resp str =
   let do_status (code, _) =
